==> knative-model-6.3.1-sources.jar: io/fabric8/knative/messaging/v1/SubscriptionStatusPhysicalSubscriptionFluentImpl.java <==
package io.fabric8.knative.messaging.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubscriptionStatusPhysicalSubscriptionFluentImpl<A extends SubscriptionStatusPhysicalSubscriptionFluent<A>> extends BaseFluent<A> implements SubscriptionStatusPhysicalSubscriptionFluent<A>{
  public SubscriptionStatusPhysicalSubscriptionFluentImpl() {
  }
  public SubscriptionStatusPhysicalSubscriptionFluentImpl(SubscriptionStatusPhysicalSubscription instance) {
    this.withDeadLetterSinkUri(instance.getDeadLetterSinkUri()); 
    this.withReplyUri(instance.getReplyUri()); 
    this.withSubscriberUri(instance.getSubscriberUri()); 
  }
  private String deadLetterSinkUri;
  private String replyUri;
  private String subscriberUri;
  public String getDeadLetterSinkUri() {
    return this.deadLetterSinkUri;
  }
  public A withDeadLetterSinkUri(String deadLetterSinkUri) {
    this.deadLetterSinkUri=deadLetterSinkUri; return (A) this;
  }
  public Boolean hasDeadLetterSinkUri() {
    return this.deadLetterSinkUri != null;
  }
  public String getReplyUri() {
    return this.replyUri;
  }
  public A withReplyUri(String replyUri) {
    this.replyUri=replyUri; return (A) this;
  }
  public Boolean hasReplyUri() {
    return this.replyUri != null;
  }
  public String getSubscriberUri() {
    return this.subscriberUri;
  }
  public A withSubscriberUri(String subscriberUri) {
    this.subscriberUri=subscriberUri; return (A) this;
  }
  public Boolean hasSubscriberUri() {
    return this.subscriberUri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubscriptionStatusPhysicalSubscriptionFluentImpl that = (SubscriptionStatusPhysicalSubscriptionFluentImpl) o;
    if (deadLetterSinkUri != null ? !deadLetterSinkUri.equals(that.deadLetterSinkUri) :that.deadLetterSinkUri != null) return false;
    if (replyUri != null ? !replyUri.equals(that.replyUri) :that.replyUri != null) return false;
    if (subscriberUri != null ? !subscriberUri.equals(that.subscriberUri) :that.subscriberUri != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(deadLetterSinkUri,  replyUri,  subscriberUri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deadLetterSinkUri != null) { sb.append("deadLetterSinkUri:"); sb.append(deadLetterSinkUri + ","); }
    if (replyUri != null) { sb.append("replyUri:"); sb.append(replyUri + ","); }
    if (subscriberUri != null) { sb.append("subscriberUri:"); sb.append(subscriberUri); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/messaging/v1/SubscriptionStatusPhysicalSubscriptionFluentImpl.java <==
package io.fabric8.knative.messaging.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubscriptionStatusPhysicalSubscriptionFluentImpl<A extends SubscriptionStatusPhysicalSubscriptionFluent<A>> extends BaseFluent<A> implements SubscriptionStatusPhysicalSubscriptionFluent<A>{
  public SubscriptionStatusPhysicalSubscriptionFluentImpl() {
  }
  public SubscriptionStatusPhysicalSubscriptionFluentImpl(SubscriptionStatusPhysicalSubscription instance) {
    if (instance != null) {
      this.withDeadLetterSinkUri(instance.getDeadLetterSinkUri());
      this.withReplyUri(instance.getReplyUri());
      this.withSubscriberUri(instance.getSubscriberUri());
    }
  }
  private String deadLetterSinkUri;
  private String replyUri;
  private String subscriberUri;
  public String getDeadLetterSinkUri() {
    return this.deadLetterSinkUri;
  }
  public A withDeadLetterSinkUri(String deadLetterSinkUri) {
    this.deadLetterSinkUri=deadLetterSinkUri; return (A) this;
  }
  public Boolean hasDeadLetterSinkUri() {
    return this.deadLetterSinkUri != null;
  }
  public String getReplyUri() {
    return this.replyUri;
  }
  public A withReplyUri(String replyUri) {
    this.replyUri=replyUri; return (A) this;
  }
  public Boolean hasReplyUri() {
    return this.replyUri != null;
  }
  public String getSubscriberUri() {
    return this.subscriberUri;
  }
  public A withSubscriberUri(String subscriberUri) {
    this.subscriberUri=subscriberUri; return (A) this;
  }
  public Boolean hasSubscriberUri() {
    return this.subscriberUri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionStatusPhysicalSubscriptionFluentImpl that = (SubscriptionStatusPhysicalSubscriptionFluentImpl) o;
    if (!java.util.Objects.equals(deadLetterSinkUri, that.deadLetterSinkUri)) return false;

    if (!java.util.Objects.equals(replyUri, that.replyUri)) return false;

    if (!java.util.Objects.equals(subscriberUri, that.subscriberUri)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(deadLetterSinkUri,  replyUri,  subscriberUri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deadLetterSinkUri != null) { sb.append("deadLetterSinkUri:"); sb.append(deadLetterSinkUri + ","); }
    if (replyUri != null) { sb.append("replyUri:"); sb.append(replyUri + ","); }
    if (subscriberUri != null) { sb.append("subscriberUri:"); sb.append(subscriberUri); }
    sb.append("}");
    return sb.toString();
  }
  
}
